#
# spec file for package python-pypuppetdb
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-pypuppetdb
Version:        2.5.1
Release:        1.8
Summary:        Library to work with PuppetDB's REST API
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/nedap/pypuppetdb
Source:         https://github.com/voxpupuli/pypuppetdb/archive/v%{version}.tar.gz
BuildRequires:  %{python_module httpretty >= 0.9.6}
BuildRequires:  %{python_module pytest >= 3.0.1}
BuildRequires:  %{python_module pytest-cov >= 2.2.1}
BuildRequires:  %{python_module requests >= 2.22.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-requests >= 2.22.0
BuildArch:      noarch
%python_subpackages

%description
This library is a wrapper around the REST API providing some convinience functions and objects to request and hold data from PuppetDB.
More information: https://github.com/nedap/pypuppetdb

%prep
%setup -q -n pypuppetdb-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# https://github.com/voxpupuli/pypuppetdb/issues/227
sed -i 's:import mock:from unittest import mock:' tests/test_*.py
%pytest
# requirements-test.txt packages oddly
rm %{buildroot}/usr/requirements_for_tests/requirements-test.txt

%files %{python_files}
%doc README.md CHANGELOG.md
%license LICENSE
%{python_sitelib}/*

%changelog
* Thu Apr  7 2022 pgajdos@suse.com
- version update to 2.5.1
  2.5.1
  - ----
  - Fix TypeError exception thrown by `BaseAPI._query()` when using debug logging.
  2.5.0
  - ----
  - Python 3.10 added as a supported version
    ([#213](https://github.com/voxpupuli/pypuppetdb/pull/213))
  2.4.0
  - ----
  - Added PQL support with `pql()` method
    (PR [#201](https://github.com/voxpupuli/pypuppetdb/pull/201),
    fixes [#167](https://github.com/voxpupuli/pypuppetdb/issues/167))
  - Added ability to specify additional queries when using `Node.facts()`
    ([#127](https://github.com/voxpupuli/pypuppetdb/pull/127))
  - Improve the documentation (even more ;))
    (PR [#206](https://github.com/voxpupuli/pypuppetdb/issues/206),
    fixes [#143](https://github.com/voxpupuli/pypuppetdb/issues/143)
    and [#129](https://github.com/voxpupuli/pypuppetdb/issues/129))
  - Fixed creating `Edge` objects
    ([#202](https://github.com/voxpupuli/pypuppetdb/issues/202))
  - Python 3.9 added as a supported version
    ([#203](https://github.com/voxpupuli/pypuppetdb/pull/203))
  2.3.0
  - ----
  - Added support for `with` statement
    ([#185](https://github.com/voxpupuli/pypuppetdb/pull/185))
  - Added explicit `disconnect()` method
    ([#185](https://github.com/voxpupuli/pypuppetdb/pull/185))
  - Improved the documentation on [Read the Docs](https://pypuppetdb.readthedocs.io/en/latest/)
    and in the project's README
    ([#190](https://github.com/voxpupuli/pypuppetdb/pull/190))
- do not require python-mock for build
* Fri Aug  7 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 2.2.0
  * Loosen requirements and drop six
- Drop loosen-requirements.patch
* Fri Mar 20 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 2.1.0
  * Dropping old python 2.7/3.5 and ensuring 3 latest versions are supported
  * Adding mypy + cleanup + further removal of python2 code
  * Bugfix: Httpretty is not used outside tests and breaks install on newer python versions for some systems
  * Add option to get nodes without using event-counts
  * define the project status as stable
  * bundle requirements-test.txt in python package
  * Bugfix: Fixed metric() function to query the new v2 endpoint based on Jolokia
  * added few new parameters
- Added patch loosen-requirements.patch
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.1.0:
  * deduplicate dependencylist
  * QueryBuilder.py: Use native data structures for internal representation
  * Add support for the Command API
* Tue Aug 27 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.0.0
  * QueryBuilder: Added support for FromOperator, arrays and FromOperator
  * New endpoint: status
  * POST query in request body
* Thu Feb 14 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Tue Feb 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop not-needed devel dependency
* Tue Feb  5 2019 joop.boonen@opensuse.org
- Build version 0.3.3
  * Add support for authentication with tokens
  * Fix bug with parsing results from inventory endpoint
- Build version 0.3.2
  * Fixed noop puppet runs reporting unchanged instead of noop.
  * Fixed unreported nodes shown as 'noop' in puppetdb > 4.1.0.
  * Add Inventory API endpoint for PuppetDB 4.2.0.
  * Support for producer field on catalogs, facts and report types.
- Build version 0.3.1
  * Fixed a datetime related bug in :func:`pypuppetdb.api.nodes()` that caused
    all returned nodes to be an unreported status
- Build version 0.3.0
  * New QueryBuilder module allows users to build PuppetDB queries in an
    Object-Oriented fashion.
  * Adding support for new fields provided in PuppetDB 4.1.0.
- Build version 0.2.3
  * Removed deprecation of :func:`pypuppetdb.types.Report.events()`. Expanded
    resource events data timestamps are not parseable.
  * Escaping additional path parameters passed to _url() with urllib.quote
- Build version 0.2.2
  * Fixed URL Encoding found when querying the specific value of a macaddress
    fact.
  * Adding support for PuppetDB 4.0.0 information. Namely Adding a catalog_uuid
    attribute to the Catalog type object. Adding code_id, catalog_uuid and
    cached_catalog_status attributes to the Report type object.
  * Removing unneeded sudo option from .travis.yml, this gave unnecessary
    warning in the test environment.
  * Updating the files under docs/ so https://pypuppetdb.readthedocs.org/en/latest/
    can be updated
  * Deprecating :func:`pypuppetdb.types.Report.events()` in favour of the new
    events list variable.
  * Renaming test-requirements.txt to requirements.txt
- Build version 0.2.1
  * Adding a version comparison utility function using examples provided in
    http://stackoverflow.com/questions/1714027/version-number-comparison
  * Adding a new variable latest_report_hash to the Node object. Default
    None but is given a real value from the field of the same name in the
    Nodes endpoint available in PuppetDB 3.2 or higher.
  * Allowing support for 'GET' AND 'POST' requests in the api _query()
    function. This will allow clients to send requests to the PuppetDB that
    are too long for a GEt request query string
  * Adding a node field, code_id, to the Catalog object using the field of
    the same name from the Catalogs endpoint (currently unused as of
    PuppetDB 3.2.2)
  * Adding test cases for new features EXCEPT the GET and POST update.
- Build version 0.2.0
  * Version bump to 0.2.0
  * Adding support for v4 of the Query API
  * Removing v2 and v3 api functions as per changelog
  * pypuppetdb will no longer support multiple API versions, removing the
    api_version attribute from pypuppetdb.connect()
  * All clients must remove the api_version attribute from the connect function,
    or the starting number, since it is no longer supported
  * Removing all NotImplemented errors in the function of BaseAPI and filled
    them with the real code
* Thu Feb 13 2014 aboe76@gmail.com
- Initial release
